summaryrefslogtreecommitdiff
path: root/lib/twitter.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/twitter.php')
-rw-r--r--lib/twitter.php7
1 files changed, 3 insertions, 4 deletions
diff --git a/lib/twitter.php b/lib/twitter.php
index 280cdb0a3..7546ffa98 100644
--- a/lib/twitter.php
+++ b/lib/twitter.php
@@ -1,7 +1,7 @@
<?php
/*
* Laconica - a distributed open-source microblogging tool
* Copyright (C) 2008, 2009, Control Yourself, Inc.
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
@@ -17,7 +17,7 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -255,4 +255,3 @@ function remove_twitter_link($flink)
}
}
-
@@ -1,7 +1,7 @@
<?php
/*
- * Laconica - a distributed open-source microblogging tool
- * Copyright (C) 2008, 2009, Control Yourself, Inc.
+ * StatusNet - the distributed open-source microblogging tool
+ * Copyright (C) 2008, 2009, StatusNet, Inc.
*
* This program is free software: you can redistribute it and/or modify